/*jslint node: true, nomen: true*/
'use strict';

var watchify = require('watchify');
var errorify = require('errorify');
var reactify = require('reactify');
var browserify = require('browserify');
var gulp = require('gulp');
var source = require('vinyl-source-stream');
var path = require("path");

var paths = {
    dist: './dist/',
    local:  './local/',
    src:    './src/',
    react:  'react'
};

var entry = 'app.js';

var options = {
    cache:        {},
    packageCache: {},
    transform:    [reactify],
    debug:        true // sourcemapping
};

function bundle(w, e) {
    return w.bundle()
        .pipe(source(e.replace('.js', '-bundle.js')))
        .pipe(gulp.dest(paths.dist));
}

gulp.task('browserify:watch', function () {
    options.entries = [path.join(paths.src, paths.react, entry)];
    options.plugin = [watchify, errorify];

    var w = browserify(options);

    w.on('update', function () {
        bundle(w, entry);
    });

    w.on('log', function (msg) {
        console.log(msg);
    });

    bundle(w, entry);

    return w;
});

gulp.task('browserify:build', function () {
    options.entries = [path.join(paths.src, paths.react, entry)];
    options.plugin = [errorify];

    return bundle(browserify(options), entry);
});
